'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactUikitBase = require('react-uikit-base');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Text = function Text(props) {
  // CSS classes
  var heading = {
    h1: 'uk-h1',
    h2: 'uk-h2',
    h3: 'uk-h3',
    h4: 'uk-h4',
    h5: 'uk-h5',
    h6: 'uk-h6'
  };

  var cssClassNames = _reactUikitBase.helpers.cleanClasses([props.classes, props.bold ? 'uk-text-bold' : null, props.context ? 'uk-text-' + props.context : null, props.heading ? heading[props.heading] : null, props.size ? 'uk-text-' + props.size : null]);

  // Remove non valid html attributes
  var ignoreProps = ['bold', 'classes', 'context', 'heading', 'href', 'kitid', 'size', 'type'];

  var cleanProps = _reactUikitBase.helpers.cleanProps(ignoreProps)(props);

  var attr = _extends({}, cleanProps, (0, _reactUikitBase.events)(props), {
    className: cssClassNames,
    'data-kitid': props.kitid
  });

  // Elements
  var type = {
    a: _react2.default.createElement(
      'a',
      _extends({ href: props.href }, attr),
      props.children
    ),

    abbr: _react2.default.createElement(
      'abbr',
      attr,
      props.children
    ),

    code: _react2.default.createElement(
      'code',
      attr,
      props.children
    ),

    del: _react2.default.createElement(
      'del',
      attr,
      props.children
    ),

    dfn: _react2.default.createElement(
      'dfn',
      _extends({}, attr, { title: props.title }),
      props.children
    ),

    em: _react2.default.createElement(
      'em',
      attr,
      props.children
    ),

    h1: _react2.default.createElement(
      'h1',
      attr,
      props.children
    ),

    h2: _react2.default.createElement(
      'h2',
      attr,
      props.children
    ),

    h3: _react2.default.createElement(
      'h3',
      attr,
      props.children
    ),

    h4: _react2.default.createElement(
      'h4',
      attr,
      props.children
    ),

    h5: _react2.default.createElement(
      'h5',
      attr,
      props.children
    ),

    h6: _react2.default.createElement(
      'h6',
      attr,
      props.children
    ),

    hr: _react2.default.createElement('hr', _extends({}, attr, { className: 'uk-article-divider ' + cssClassNames })),

    ins: _react2.default.createElement(
      'ins',
      attr,
      props.children
    ),

    mark: _react2.default.createElement(
      'mark',
      attr,
      props.children
    ),

    q: _react2.default.createElement(
      'q',
      attr,
      props.children
    ),

    p: _react2.default.createElement(
      'p',
      attr,
      props.children
    ),

    small: _react2.default.createElement(
      'small',
      attr,
      props.children
    ),

    span: _react2.default.createElement(
      'span',
      attr,
      props.children
    ),

    strong: _react2.default.createElement(
      'strong',
      attr,
      props.children
    )
  };

  // Return Component
  return type[props.type] || type['p'];
};

Text.propTypes = {
  bold: _react2.default.PropTypes.bool,
  classes: _react2.default.PropTypes.array,
  context: _react2.default.PropTypes.oneOf(['muted', 'primary', 'success', 'warning', 'danger', 'contrast']),
  heading: _react2.default.PropTypes.oneOf(['h1', 'h2', 'h3', 'h4', 'h5', 'h6']),
  href: _react2.default.PropTypes.string,
  kitid: _react2.default.PropTypes.string,
  size: _react2.default.PropTypes.oneOf(['small', 'large']),
  type: _react2.default.PropTypes.oneOf(['a', 'abbr', 'code', 'del', 'dfn', 'em', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'hr', 'ins', 'mark', 'q', 'p', 'small', 'span', 'strong'])
};

exports.default = (0, _reactUikitBase.base)(Text);